@@ -1,12 +1,12 @@
 use 5.014;
 
 package Mojo::UserAgent::Mockable;
-$Mojo::UserAgent::Mockable::VERSION = '1.41';
+$Mojo::UserAgent::Mockable::VERSION = '1.42';
 use warnings::register;
 
 use Carp;
 use JSON::MaybeXS;
-use Mojolicious;
+use Mojolicious 6.0;
 use Mojo::Base 'Mojo::UserAgent';
 use Mojo::Util qw/secure_compare/;
 use Mojo::UserAgent::Mockable::Serializer;
@@ -243,7 +243,7 @@ Mojo::UserAgent::Mockable - A Mojo User-Agent that can record and play back requ
 
 =head1 VERSION
 
-version 1.41
+version 1.42
 
 =head1 SYNOPSIS
 
